'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _config = require('./config');

var _config2 = _interopRequireDefault(_config);

var _User = require('./User');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Returns a key of permissions functions that each return boolean to indicate authorization.
 * Usage:
 *      permit(pipeline).create();
 *
 * @param subject
 * @returns {{read: (function()), create: (function()), start: (function()), stop: (function())}}
 */
/**
 * Created by cmeyers on 9/16/16.
 */

var permit = function permit(subject) {
    var checkPermissions = function checkPermissions(permissionName) {
        return subject && subject.permissions && !!subject.permissions[permissionName];
    };

    return {
        read: function read() {
            return checkPermissions('read');
        },
        configure: function configure() {
            return checkPermissions('configure');
        },
        create: function create() {
            return checkPermissions('create');
        },
        start: function start() {
            return checkPermissions('start');
        },
        stop: function stop() {
            return checkPermissions('stop');
        }
    };
};

function isSecurityEnabled() {
    return !!_config2.default.getSecurityConfig().enabled;
}

function isAnonymousUser() {
    return _User.User.current().isAnonymous();
}

exports.default = {
    permit: permit,
    isSecurityEnabled: isSecurityEnabled,
    isAnonymousUser: isAnonymousUser
};
//# sourceMappingURL=security.js.map
